#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

/**/

#include "Common.h"

/**/

//----------------------------------------------------------
//Function for the event procedure
//----------------------------------------------------------
void MainTimerUpdate(WSCbase* object){
  //do something...
	gHeadLine.UpdateTimer();
}
static WSCfunctionRegister  op("MainTimerUpdate",(void*)MainTimerUpdate);
